@@ -1020,7 +1020,7 @@ window.cockpit_po = {
  ],
  "Unsupported shell. Check the journal for details.": [
   null,
-  ""
+  "Shell no soportado. Revisa el registro para más detalles."
  ],
  "Untrusted host": [
   null,
